@@ -16,21 +16,21 @@ class ShapefileCollectionTest(unittest.TestCase):
         c = collection("docs/data/test_uk.shp", "r")
         self.failUnlessEqual(c.name, "test_uk")
         self.failUnlessEqual(c.mode, "r")
-        self.failUnlessEqual(c.opened, True)
-        self.assertRaises(IOError, c.open)
         self.failUnless(iter(c))
         c.close()
         self.assertRaises(ValueError, iter, c)
-        self.failUnlessEqual(c.opened, False)
-        self.assertRaises(IOError, c.close)
 
     def test_len(self):
         c = collection("docs/data/test_uk.shp", "r")
         self.failUnlessEqual(len(c), 48)
+        c.close()
+        self.failUnlessEqual(len(c), 48)
 
     def test_driver(self):
         c = collection("docs/data/test_uk.shp", "r")
         self.failUnlessEqual(c.driver, "ESRI Shapefile")
+        c.close()
+        self.failUnlessEqual(c.driver, "ESRI Shapefile")
 
     def test_schema(self):
         c = collection("docs/data/test_uk.shp", "r")
@@ -43,12 +43,18 @@ class ShapefileCollectionTest(unittest.TestCase):
         self.failUnlessEqual(c.crs['ellps'], 'WGS84')
         self.failUnless(c.crs['no_defs'])
 
+    def test_bounds(self):
+        c = collection("docs/data/test_uk.shp", "r")
+        self.failUnlessAlmostEqual(c.bounds[0], -8.621389, 6)
+        self.failUnlessAlmostEqual(c.bounds[1], 49.911659, 6)
+        self.failUnlessAlmostEqual(c.bounds[2], 1.749444, 6)
+        self.failUnlessAlmostEqual(c.bounds[3], 60.844444, 6)
+
     def test_context(self):
         with collection("docs/data/test_uk.shp", "r") as c:
             self.failUnlessEqual(c.name, "test_uk")
-            self.failUnlessEqual(c.opened, True)
             self.failUnlessEqual(len(c), 48)
-        self.failUnlessEqual(c.opened, False)
+        self.failUnlessEqual(c.closed, True)
 
     def test_iter_one(self):
         with collection("docs/data/test_uk.shp", "r") as c:
@@ -99,6 +105,27 @@ class ShapefileWriteCollectionTest(unittest.TestCase):
             self.assertRaises(IOError, c.filter)
 
     def test_write_point(self):
+        with collection("docs/data/test_uk.shp", "r") as input:
+            schema = input.schema.copy()
+            schema['geometry'] = 'Point'
+            with collection(
+                    "test_write_point.shp", "w", "ESRI Shapefile", schema
+                    ) as output:
+                for f in input.filter(bbox=(-5.0, 55.0, 0.0, 60.0)):
+                    f['geometry'] = {
+                        'type': 'Point',
+                        'coordinates': f['geometry']['coordinates'][0][0] }
+                    output.writerecords([f])
+                self.failUnlessEqual(len(output._buffer), 7)
+                self.failUnlessEqual(len(output), 7)
+        
+        self.failUnlessEqual(len(output), 7)
+        self.failUnlessAlmostEqual(output.bounds[0], -3.231389, 6)
+        self.failUnlessAlmostEqual(output.bounds[1], 51.614998, 6)
+        self.failUnlessAlmostEqual(output.bounds[2], -1.180556, 6)
+        self.failUnlessAlmostEqual(output.bounds[3], 60.224998, 6)
+
+    def test_write_point2(self):
         with collection("docs/data/test_uk.shp", "r") as input:
             schema = input.schema.copy()
             schema['geometry'] = 'Point'
@@ -110,6 +137,9 @@ class ShapefileWriteCollectionTest(unittest.TestCase):
                         'type': 'Point',
                         'coordinates': f['geometry']['coordinates'][0][0] }
                     output.write(f)
+                self.failUnlessEqual(len(output._buffer), 7)
+                self.failUnlessEqual(len(output), 7)
+        self.failUnlessEqual(len(output), 7)
 
     def test_write_polygon_with_crs(self):
         with collection("docs/data/test_uk.shp", "r") as input:
